summaryrefslogtreecommitdiffstats
path: root/models/repo_mirror.go
diff options
context:
space:
mode:
authorLunny Xiao <xiaolunwen@gmail.com>2017-10-02 00:52:35 +0800
committerLauris BH <lauris@nix.lv>2017-10-01 19:52:35 +0300
commita8717e5e3ace4dd226547faae9c3a44616bbf6f0 (patch)
tree524dc024dec64131406486556951a53655ad8510 /models/repo_mirror.go
parent1ad902d5298202d5be14fd5a9c8ed6ce781a23c8 (diff)
downloadgitea-a8717e5e3ace4dd226547faae9c3a44616bbf6f0.tar.gz
gitea-a8717e5e3ace4dd226547faae9c3a44616bbf6f0.zip
Use AfterLoad instead of AfterSet on Structs (#2628)
* use AfterLoad instead of AfterSet on Structs * fix the comments on AfterLoad * fix the comments on action AfterLoad
Diffstat (limited to 'models/repo_mirror.go')
-rw-r--r--models/repo_mirror.go20
1 files changed, 8 insertions, 12 deletions
diff --git a/models/repo_mirror.go b/models/repo_mirror.go
index 60d4f9f05a..0b6e130aed 100644
--- a/models/repo_mirror.go
+++ b/models/repo_mirror.go
@@ -55,24 +55,20 @@ func (m *Mirror) BeforeUpdate() {
}
}
-// AfterSet is invoked from XORM after setting the value of a field of this object.
-func (m *Mirror) AfterSet(colName string, _ xorm.Cell) {
+// AfterLoad is invoked from XORM after setting the values of all fields of this object.
+func (m *Mirror) AfterLoad(session *xorm.Session) {
if m == nil {
return
}
var err error
- switch colName {
- case "repo_id":
- m.Repo, err = GetRepositoryByID(m.RepoID)
- if err != nil {
- log.Error(3, "GetRepositoryByID[%d]: %v", m.ID, err)
- }
- case "updated_unix":
- m.Updated = time.Unix(m.UpdatedUnix, 0).Local()
- case "next_update_unix":
- m.NextUpdate = time.Unix(m.NextUpdateUnix, 0).Local()
+ m.Repo, err = getRepositoryByID(session, m.RepoID)
+ if err != nil {
+ log.Error(3, "getRepositoryByID[%d]: %v", m.ID, err)
}
+
+ m.Updated = time.Unix(m.UpdatedUnix, 0).Local()
+ m.NextUpdate = time.Unix(m.NextUpdateUnix, 0).Local()
}
// ScheduleNextUpdate calculates and sets next update time.